summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/3526intf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/3526intf.cpp')
-rw-r--r--src/devices/sound/3526intf.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/3526intf.cpp b/src/devices/sound/3526intf.cpp
index dd81b0d7eb0..dce29c78440 100644
--- a/src/devices/sound/3526intf.cpp
+++ b/src/devices/sound/3526intf.cpp
@@ -60,10 +60,10 @@ void ym3526_device::timer_handler(int c,const attotime &period)
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void ym3526_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void ym3526_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
ym3526_update_one(m_chip, outputs[0], samples);
}
@@ -109,7 +109,7 @@ void ym3526_device::calculate_rates()
if (m_stream != nullptr)
m_stream->set_sample_rate(rate);
else
- m_stream = machine().sound().stream_alloc(*this,0,1,rate);
+ m_stream = stream_alloc_legacy(0,1,rate);
}
//-------------------------------------------------
@@ -60,10 +60,10 @@ void ym3526_device::timer_handler(int c,const attotime &period)
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------